dfp library
Classes
-
Err<
T, E> - Contains the error value
-
None<
T> - No value.
-
Ok<
T, E> - Contains the success value
-
Option<
T> -
Option<A>is a container for an optional value of typeA. If the value of typeAis present, theOption<A>is an instance ofSome<A>, containing the present value of typeA. If the value is absent, theOption<A>is an instance ofNone. -
Result<
T, E> - Result is a type that represents either success (Ok) or failure (Err).
-
Some<
T> -
Some value of type
T.